@@ -1,5 +1,5 @@
 /*
- * $Id: func.h,v 1.5 2008/02/02 08:15:14 sezero Exp $
+ * $Id: func.h,v 1.6 2008/07/02 17:15:56 sezero Exp $
  * This file is a part of the lxSplit tool sources.
  *
  * Copyright (c) 2001 Richard Stellingwerff <remenic@gmail.com>
@@ -27,7 +27,9 @@
 #ifndef __FUNC_H
 #define __FUNC_H
 
+#if 0
 uintmax_t available_diskspace (const char *path);
+#endif
 char *strip_path (const char *filename);
 char *shorten_path (const char *cfilename);
 
